filterEGenes = function(Porig, D, Padj=NULL, ntop=100, fpr=0.05, adjmethod="bonferroni", cutoff=0.05){
	if(is.null(Padj))
		Padj = apply(Porig, 2, p.adjust, method="fdr")	
	ntop = min(nrow(Porig),ntop)
	n = ncol(Porig)
	I1 = apply(Porig,2,function(x) order(x)[1:ntop])
	I1 = unique(as.vector(I1))  # Länge ist abhängig von P!	
	print(paste("Selecting top",ntop," genes from each list -->",length(I1),"genes total"))				
	disc = (Padj[I1,] <= fpr)*1		
	nsig = colSums(Padj[I1,] < fpr)
	N = nrow(disc)
	patterns = unique(disc)		
	patterns = patterns[-which(apply(patterns,1,function(r) all(r == 0))),]	
	if(nrow(patterns) < 1)
		stop("No patterns found!")	
	idx = apply(patterns,1, function(p){
		cl = which(apply(disc,1, function(r) all(r == p)))
	})
	nobserved = sapply(idx, length)
	patterns = patterns[nobserved > 0,]
	idx = idx[nobserved > 0]
	nobserved = nobserved[nobserved > 0]
	cat("Testing ", nrow(patterns), " patterns\n")
	p.values = sapply(1:nrow(patterns), function(j){
		p = patterns[j,]		
		pexpected = max(0,prod((fpr*p*nsig + (1-fpr)*(1-p)*(N-nsig))/N))
		p.value = binom.test(nobserved[j], N, pexpected, alternative="greater")$p.value
		cat("pattern ", p, ": (#observed = ", nobserved[j], ", #expected = ", floor(pexpected*N), ", raw p-value = ", p.value,")\n")		
		p.value
	})
	cat("\n")
	p.values = p.adjust(p.values,method=adjmethod)
	if(!any(p.values < cutoff))
		stop("No significant patterns found!\n")
	patterns = patterns[p.values < cutoff,]	
	idx = idx[p.values < cutoff]
	nobserved = nobserved[p.values < cutoff]
	p.values = p.values[p.values < cutoff]
	I = I1[unlist(idx)]	
	cat(length(p.values), " significant patterns -->", length(I), "E-genes in total\n")
	D = D[I,]	
	list(selected=I, dat=D, patterns=patterns, nobserved=nobserved, p.values=p.values)
}

getRelevantEGenes <- function(Phi, D, para=NULL, hyperpara=NULL,Pe=NULL,Pm=NULL,lambda=0, delta=1, type="CONTmLLDens", nEgenes=min(10*nrow(Phi), nrow(D))){			
	if(type == "CONTmLLRatio"){		
		sc = score(list(Phi), D, type=type, para=para, hyperpara=hyperpara, Pe=Pe, Pm=Pm, lambda=lambda, delta=delta, verbose=FALSE, graphClass="matrix")				
		sel = which(unlist(sc$mappos) != "NA")			
	}
	else{						
		L <- sapply(1:nrow(D), function(idx){						
			if(!is.null(Pe))
				Pei = t(as.matrix(Pe[idx,]))
			else
				Pei = NULL
			score(list(Phi), t(as.matrix(D[idx,])), type=type, para=para, hyperpara=hyperpara, Pe=Pei, Pm=Pm, lambda=lambda, verbose=FALSE, graphClass="matrix")$mLL	
		})			
		L = L/sum(L)		
		if(type %in% c("CONTmLLDens"))
			nEgenes = max(10,length(which(L>0)))		
		sel <- unique(order(L,decreasing=TRUE)[1:nEgenes])
		sc = score(list(Phi), D[sel,], type=type, para=para, hyperpara=hyperpara, Pe=Pe[sel,], Pm=Pm, lambda=lambda, delta=delta, verbose=FALSE, graphClass="matrix")									
	}					
	list(selected=sel, mLL=sc$mLL, pos=unlist(sc$pos), mappos=unlist(sc$mappos))
}
